@@ -78,7 +78,7 @@ namespace Tomboy
 
 			// NOTE: It is important not to use the Preferences
 			//       class before this call.
-			Initialize ("tomboy", "tomboy", "tomboy", args);
+			Initialize ("tomboy", "Tomboy", "tomboy", args);
 
 			// Add private icon dir to search path
 			icon_theme = Gtk.IconTheme.Default;
@@ -205,7 +205,8 @@ namespace Tomboy
 			// instead, launch the Search All Notes window so the user can
 			// can still use Tomboy.
 #if !MAC
-			if (tray_icon_showing == false)
+			if (tray_icon_showing == false &&
+			    (bool) Preferences.Get (Preferences.ENABLE_TRAY_ICON))
 				ActionManager ["ShowSearchAllNotesAction"].Activate ();
 #endif
 			
